aboutsummaryrefslogtreecommitdiff
path: root/gcc/cpplib.h
diff options
context:
space:
mode:
authorNeil Booth <neil@daikokuya.co.uk>2003-04-23 22:44:06 +0000
committerNeil Booth <neil@gcc.gnu.org>2003-04-23 22:44:06 +0000
commit6338b35872d465cf27fdbbc43b5a146363c8f246 (patch)
treee4f819e101d1dc188ae9d2012e0cb8ab2239160d /gcc/cpplib.h
parent06f5e63748eeb66140858914bbffb149406789a9 (diff)
downloadgcc-6338b35872d465cf27fdbbc43b5a146363c8f246.zip
gcc-6338b35872d465cf27fdbbc43b5a146363c8f246.tar.gz
gcc-6338b35872d465cf27fdbbc43b5a146363c8f246.tar.bz2
Makefile.in (c-lex.o, [...]): Update.
* Makefile.in (c-lex.o, LIBCPP_OBJS, cpplex.o): Update. * c-lex.c (MULTIBYTE_CHARS): Remove conditionals. (lex_string): Take cpp_string with full spelling. (cb_ident): Update. (c_lex): Update diagnostics. * cpplex.c (SPELL_NUMBER, SPELL_STRING): Combine into SPELL_LITERAL. (create_literal): New. (lex_string): Unterminated literals have type CPP_OTHER. (_cpp_lex_direct): Update calls to lex_string. Use create_literal for CPP_OTHER. (cpp_token_len, cpp_spell_token, cpp_output_token): Simplify. (_cpp_equiv_tokens, cpp_interpret_charconst): Update. * cpplib.c (parse_include, do_line, do_linemarker, destringize_and_run): Update for token storing full spelling. * cpplib.h: Update token spelling types. * cppmacro.c (stringify_arg, check_trad_stringification): Update for token storing full spelling. cp: * Make-lang.in (lex.o): Remove mbchar.h. * lex.c (MULTIBYTE_CHARS): Lose. * parser.c (cp_lexer_get_preprocessor_token): CPP_OTHER handled in c-lex.c. testsuite: * gcc.dg/cpp/include2.c: Update. * gcc.dg/cpp/multiline-2.c: New. * gcc.dg/cpp/multiline.c: Update. * gcc.dg/cpp/strify2.c: Update. * gcc.dg/cpp/trad/literals-2.c: Update. From-SVN: r66019
Diffstat (limited to 'gcc/cpplib.h')
-rw-r--r--gcc/cpplib.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/gcc/cpplib.h b/gcc/cpplib.h
index 875fe5b..90977d1 100644
--- a/gcc/cpplib.h
+++ b/gcc/cpplib.h
@@ -124,18 +124,18 @@ struct file_name_map_list;
OP(CPP_ATSIGN, "@") /* used in Objective-C */ \
\
TK(CPP_NAME, SPELL_IDENT) /* word */ \
- TK(CPP_NUMBER, SPELL_NUMBER) /* 34_be+ta */ \
+ TK(CPP_NUMBER, SPELL_LITERAL) /* 34_be+ta */ \
\
- TK(CPP_CHAR, SPELL_STRING) /* 'char' */ \
- TK(CPP_WCHAR, SPELL_STRING) /* L'char' */ \
- TK(CPP_OTHER, SPELL_NUMBER) /* stray punctuation */ \
+ TK(CPP_CHAR, SPELL_LITERAL) /* 'char' */ \
+ TK(CPP_WCHAR, SPELL_LITERAL) /* L'char' */ \
+ TK(CPP_OTHER, SPELL_LITERAL) /* stray punctuation */ \
\
- TK(CPP_STRING, SPELL_STRING) /* "string" */ \
- TK(CPP_WSTRING, SPELL_STRING) /* L"string" */ \
- TK(CPP_HEADER_NAME, SPELL_STRING) /* <stdio.h> in #include */ \
+ TK(CPP_STRING, SPELL_LITERAL) /* "string" */ \
+ TK(CPP_WSTRING, SPELL_LITERAL) /* L"string" */ \
+ TK(CPP_HEADER_NAME, SPELL_LITERAL) /* <stdio.h> in #include */ \
\
- TK(CPP_COMMENT, SPELL_NUMBER) /* Only if output comments. */ \
- /* SPELL_NUMBER happens to DTRT. */ \
+ TK(CPP_COMMENT, SPELL_LITERAL) /* Only if output comments. */ \
+ /* SPELL_LITERAL happens to DTRT. */ \
TK(CPP_MACRO_ARG, SPELL_NONE) /* Macro argument. */ \
TK(CPP_PADDING, SPELL_NONE) /* Whitespace for cpp0. */